telephonyserverplugins/ctsydispatchlayer/inc/ccallcontroldispatcher.h
branchRCL_3
changeset 14 7ef16719d8cb
parent 0 3553901f7fa8
child 24 6638e7f4bd8f
--- a/telephonyserverplugins/ctsydispatchlayer/inc/ccallcontroldispatcher.h	Fri Feb 19 23:59:33 2010 +0200
+++ b/telephonyserverplugins/ctsydispatchlayer/inc/ccallcontroldispatcher.h	Fri Mar 12 15:49:38 2010 +0200
@@ -218,6 +218,7 @@
     MLtsyDispatchCallControlSendDtmfTones* iLtsyDispatchCallControlSendDtmfTones;
     MLtsyDispatchCallControlGetIdentityServiceStatus* iLtsyDispatchCallControlGetIdentityServiceStatus;
     MLtsyDispatchCallControlSwap* iLtsyDispatchCallControlSwap;
+    MLtsyDispatchCallControlSwap* iLtsyDispatchCallControlSingleSwap;
     MLtsyDispatchCallControlLoanDataPort* iLtsyDispatchCallControlLoanDataPort;
     MLtsyDispatchCallControlRecoverDataPort* iLtsyDispatchCallControlRecoverDataPort;
     MLtsyDispatchCallControlStartDtmfTone* iLtsyDispatchCallControlStartDtmfTone;
@@ -283,13 +284,13 @@
      * These Call IDs should only have a value != -1 when there is a pending swap
      * operation.
      */
-    TInt iSwapHeldCallId;
-    TInt iSwapConnectedCallId;
+    TInt iSwapCallId;
+    TInt iSecondSwapCallId;
 
     /**
      * These are the two Call IDs of the calls on which a transfer operation
      * has been requested. It is needed for the same reason as iSwapHeldCallId
      * and iSwapConnectedCallId above.
      */
     TInt iTransferHeldCallId;
     TInt iTransferSecondCallId;
@@ -283,13 +284,13 @@
     /**
      * These are the two Call IDs of the calls on which a transfer operation
-     * has been requested. It is needed for the same reason as iSwapHeldCallId
-     * and iSwapConnectedCallId above.
+     * has been requested. It is needed for the same reason as iSwapCallId
+     * and iSecondSwapCallId above.
      */
     TInt iTransferHeldCallId;